Image class

Available extensions

Constructors

Image({required int image, int? slot, Uint8List? hash, required Uint8List data})

Properties

data ↔ Uint8List
getter/setter pair
hash ↔ Uint8List?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slot ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toProto() → ProtoImage

Available on Image, provided by the ImageModelToProto extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited