McuMgrLogLevel class

Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
rawValue → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
no setter

Methods

convent() → ProtoLogMessage_LogLevel

Available on McuMgrLogLevel, provided by the McuMgrLogLevelToProto extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

values → List<McuMgrLogLevel>
no setter

Constants

application → const McuMgrLogLevel
debug → const McuMgrLogLevel
error → const McuMgrLogLevel
info → const McuMgrLogLevel
verbose → const McuMgrLogLevel
warning → const McuMgrLogLevel